==> Botan-1.5.0.tgz: Botan-1.5.0/include/libstate.h <==
/*************************************************
* Library Internal/Global State Header File      *
* (C) 1999-2006 The Botan Project                *
*************************************************/

#ifndef BOTAN_LIB_STATE_H__
#define BOTAN_LIB_STATE_H__

#include <botan/base.h>
#include <string>
#include <vector>
#include <map>

namespace Botan {

/*************************************************
* Global State Container                         *
*************************************************/
class Library_State
   {
   public:
      class Engine_Iterator
         {
         public:
            class Engine* next();
            Engine_Iterator(const Library_State& l) : lib(l) { n = 0; }
         private:
            const Library_State& lib;
            u32bit n;
         };
      friend class Engine_Iterator;

      virtual Allocator* get_allocator(const std::string& = "") const = 0;
      virtual void add_allocator(const std::string&, Allocator*) = 0;

      virtual void set_prng(RandomNumberGenerator*) = 0;
      virtual void randomize(byte[], u32bit) = 0;
      virtual void add_entropy_source(EntropySource*, bool = false) = 0;
      virtual void add_entropy(const byte[], u32bit) = 0;
      virtual void add_entropy(EntropySource&, bool) = 0;
      virtual u32bit seed_prng(bool, u32bit) = 0;

      virtual u64bit system_clock() const = 0;

      virtual void set_option(const std::string&, const std::string&,
                              const std::string&, bool = true) = 0;
      virtual std::string get_option(const std::string&,
                                     const std::string&) const = 0;
      virtual bool option_set(const std::string&,
                              const std::string&) const = 0;

      virtual void add_engine(class Engine*) = 0;

      virtual class Mutex* get_mutex() = 0;

      virtual ~Library_State() {}
   private:
      virtual class Engine* get_engine_n(u32bit) const = 0;
   };

class Default_Library_State : public Library_State
   {
   public:
      Allocator* get_allocator(const std::string& = "") const;
      void add_allocator(const std::string&, Allocator*);

      void set_prng(RandomNumberGenerator*);
      void randomize(byte[], u32bit);
      void add_entropy_source(EntropySource*, bool = false);
      void add_entropy(const byte[], u32bit);
      void add_entropy(EntropySource&, bool);
      u32bit seed_prng(bool, u32bit);

      u64bit system_clock() const;

      void set_option(const std::string&, const std::string&,
                              const std::string&, bool = true);
      std::string get_option(const std::string&, const std::string&) const;
      bool option_set(const std::string&, const std::string&) const;

      void add_engine(class Engine*);

      class Mutex* get_mutex();

      Default_Library_State(class Mutex_Factory*, class Timer*);
      ~Default_Library_State();
   private:
      class Engine* get_engine_n(u32bit) const;
      void set_default_policy();

      std::map<std::string, class Mutex*> locks;

      class Mutex_Factory* mutex_factory;
      class Timer* timer;

      std::map<std::string, std::string> settings;
      std::map<std::string, Allocator*> alloc_factory;

      RandomNumberGenerator* rng;
      std::vector<EntropySource*> entropy_sources;
      std::vector<class Engine*> engines;
   };

/*************************************************
* Global State                                   *
*************************************************/
Library_State& global_state();

}

#endif

==> Botan-1.5.1.tgz: Botan-1.5.1/include/libstate.h <==
/*************************************************
* Library Internal/Global State Header File      *
* (C) 1999-2006 The Botan Project                *
*************************************************/

#ifndef BOTAN_LIB_STATE_H__
#define BOTAN_LIB_STATE_H__

#include <botan/base.h>
#include <string>
#include <vector>
#include <map>

namespace Botan {

/*************************************************
* Global State Container Base                    *
*************************************************/
class Library_State
   {
   public:
      class Engine_Iterator
         {
         public:
            class Engine* next();
            Engine_Iterator(const Library_State& l) : lib(l) { n = 0; }
         private:
            const Library_State& lib;
            u32bit n;
         };
      friend class Engine_Iterator;

      Allocator* get_allocator(const std::string& = "") const;
      void add_allocator(const std::string&, Allocator*);

      void set_prng(RandomNumberGenerator*);
      void randomize(byte[], u32bit);
      void add_entropy_source(EntropySource*, bool = false);
      void add_entropy(const byte[], u32bit);
      void add_entropy(EntropySource&, bool);
      u32bit seed_prng(bool, u32bit);

      u64bit system_clock() const;

      void set_option(const std::string&, const std::string&,
                              const std::string&, bool = true);
      std::string get_option(const std::string&, const std::string&) const;
      bool option_set(const std::string&, const std::string&) const;

      void add_engine(class Engine*);

      class Mutex* get_mutex();

      Library_State(class Mutex_Factory*, class Timer*);
      ~Library_State();
   private:
      Library_State(const Library_State&) {}
      Library_State& operator=(const Library_State&) { return (*this); }

      class Engine* get_engine_n(u32bit) const;
      void set_default_policy();

      std::map<std::string, class Mutex*> locks;

      class Mutex_Factory* mutex_factory;
      class Timer* timer;

      std::map<std::string, std::string> settings;
      std::map<std::string, Allocator*> alloc_factory;
      mutable Allocator* cached_default_allocator;

      RandomNumberGenerator* rng;
      std::vector<EntropySource*> entropy_sources;
      std::vector<class Engine*> engines;
   };

/*************************************************
* Global State                                   *
*************************************************/
Library_State& global_state();

}

#endif
